// src/index.ts
import crypto, { pbkdf2 as deriveKey } from "crypto";
function pbkdf2({ password, salt }) {
  return new Promise((resolve, reject) => {
    deriveKey(password, salt, 1, 64, "sha256", (error, key) => {
      if (error)
        return reject(error);
      resolve(key);
    });
  });
}
function generateRandom(length = 16) {
  return Buffer.from(crypto.randomBytes(length));
}
async function aesEncrypt(data, password) {
  const salt = generateRandom();
  const iv = generateRandom();
  const key = await pbkdf2({ password, salt });
  const encryptTool = crypto.createCipheriv(
    "aes-128-cbc",
    key.subarray(0, 16),
    iv
  );
  let content = encryptTool.update(data, "utf8", "base64");
  content += encryptTool.final("base64");
  const packaged = Buffer.concat([iv, salt, Buffer.from(content, "base64")]);
  return packaged.toString("base64");
}
async function aesDecrypt(data, password) {
  const unpackaged = Buffer.from(data, "base64");
  const iv = unpackaged.subarray(0, 16);
  const salt = unpackaged.subarray(16, 32);
  const input = unpackaged.subarray(32, data.length);
  const key = await pbkdf2({ password, salt });
  const decryptTool = crypto.createDecipheriv(
    "aes-128-cbc",
    key.subarray(0, 16),
    iv
  );
  let result = decryptTool.update(input.toString("base64"), "base64", "utf8");
  result += decryptTool.final("utf8");
  return result;
}
export {
  aesDecrypt,
  aesEncrypt,
  pbkdf2
};
